pub struct AddSketch;Expand description
Adds a sketch on a plane to the part, named by the operation’s id: a
planar face, a datum plane or a frame’s plane (see [EntityRef]). The plane is
resolved when the sketch is added: a sketch on a face stays where the
face was, whatever later operations do to the face.